Code edit (2 edits merged)
Please save this source code
User prompt
while the finger is held, slightly shake the player graphic. stop this animation as soon as the finger is released
User prompt
Please fix the bug: 'Uncaught TypeError: setInterval is not a function' in or related to this line: 'self.vibrationInterval = setInterval(function () {' Line Number: 73
User prompt
while the finger is held, slightly vibrate the player graphic. stop this animation as soon as the finger is released
Code edit (1 edits merged)
Please save this source code
User prompt
instead of starting the life from the middle of the screen, always spawn it at the left edge of the screen
Code edit (3 edits merged)
Please save this source code
User prompt
move the life lower, and centralize all of it's properties in a single place, so that it's position for example is not defined in multiple places in the code, rather just one
Code edit (6 edits merged)
Please save this source code
User prompt
add the life at the top of the screen. the life bounces left and right between the left and right edges of the screen. the player can collect this
User prompt
when the tap is released and the player jumps, play the Jump sound
User prompt
while the finger is held to charge the jump, play the Charge sound. stop it as soon as the finger is released
Code edit (1 edits merged)
Please save this source code
User prompt
fix the player collision with the top edge of the screen. right now if the player's top edge hits the screen the game doesnt go to game over as it should
User prompt
fix the player collision with the top edge of the screen. right now if the player's top edge hits the screen the game doesnt go to game over as it should
User prompt
fix the player collision with the top edge of the screen. right now if the player's top edge hits the screen the game doesnt go to game over as it should
Code edit (3 edits merged)
Please save this source code
User prompt
move the player's starting position 100 pixels lower
User prompt
disable jumping while the player is in mid air. only allow jumping when the player is on the ground
Code edit (3 edits merged)
Please save this source code
User prompt
as soon as the top edge of the player touches the top part of the screen go to game over
User prompt
when ANY part of the player touches the top edge of the screen go to game over. right now this only triggers when the center of the player touches it, which is a bug
Code edit (3 edits merged)
Please save this source code
User prompt
holding the finger for just a fraction of a second should make the player jump a bit higher. there should be a minimum distance the player can jump
Code edit (1 edits merged)
Please save this source code
===================================================================
--- original.js
+++ change.js
@@ -18,9 +18,9 @@
self.jumpCharge = Math.min(60, LK.ticks - self.jumpStartTime);
} else {
self.velocityY += 1; // Gravity
if (self.jumpCharge > 0) {
- self.velocityY = -self.jumpCharge * 2; // Multiply the jump charge by 2 to increase the jump height
+ self.velocityY = -Math.max(10, self.jumpCharge * 1.2); // Multiply the jump charge by 2 to increase the jump height, with a minimum jump height of 10
self.jumpCharge = 0;
}
}
self.y += self.velocityY;
pixelated 8-bit cute sitting frog seen from the front. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
pixelated 8-bit cute jumping frog seen from the front. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
background of a pond in the middle of the nature. pixelated 8-bit. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.